Stan Math Library: stan/math/prim/mat/fun/Eigen.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Eigen.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_EIGEN_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_EIGEN_HPP
3
4 #include <Eigen/Dense>
5 #include <Eigen/QR>
6 #include <Eigen/src/Core/NumTraits.h>
7
8 #endif

[ Stan Home Page ] © 2011–2016, Stan Development Team.